@@ -196,7 +196,8 @@ def OMEGA_k(J,K, omd, Kd, dimid, dd, ft_flag):
 
     if dimid < dd - 1:  # trick: pre-convert these indices into offsets!
         #            ('trick: pre-convert these indices into offsets!')
-        k_indx = k_indx * numpy.prod(Kd[dimid+1:dd]) - 1
+        k_indx = k_indx * numpy.prod(Kd[dimid+1:dd])# - 1
+#     print(dimid, k_indx[0,0])
     """
     Note: F-order matrices must be reshaped into an 1D array before sparse matrix-vector multiplication.
     The original F-order (in Fessler and Sutton 2003) is not suitable for GPU array (C-order).
@@ -455,7 +456,7 @@ def khatri_rao_k(kd):
     for dimid in range(1, dd):
         Jprod *= kd[dimid].shape[1] #numpy.prod(Jd[:dimid + 1])
 
-        kk = block_outer_sum(kk, kd[dimid]) + 1  # outer sum of indices
+        kk = block_outer_sum(kk, kd[dimid]) #+ 1  # outer sum of indices
         kk = kk.reshape((M, Jprod), order='C')
 #         uu = numpy.einsum('mi,mj->mij', uu, ud[dimid])
 #         uu = uu.reshape((M, Jprod), order='C')
